@@ -118,10 +118,6 @@ as_ltraj.track_xyt <- function(x, ...) {
 #' @examples
 #' data(deer)
 #' d <- as_bcpa(deer)
-#' \dontrun{
-#' bcpa1 <- bcpa::WindowSweep(d, "Theta", K = 2, windowsize = 50)
-#' plot(bcpa1, type = "flat", clusterwidth = 1)
-#' }
 
 as_bcpa <- function(x, ...) {
   UseMethod("as_bcpa", x)
@@ -130,26 +126,29 @@ as_bcpa <- function(x, ...) {
 #' @export
 #' @rdname coercion
 as_bcpa.track_xyt <- function(x, ...) {
-  x <- data_frame(X = x$x_, Y = x$y_, Time = x$t_)
+  x <- tibble(X = x$x_, Y = x$y_, Time = x$t_)
   bcpa::GetVT(x, ...)
 }
 
-# as_ctmm -----------------------------------------------------------------
-# TODO
-# #' @export
-# #' @rdname coercion
-# #' @examples
-# #' data(deer)
-# #' as_ctmm(deer)
-# as_ctmm <- function(x, ...) {
-#   UseMethod("as_ctmm", x)
-# }
-#
-# #' @export
-# #' @rdname coercion
-# as_ctmm.track_xyt <- function(x, ...) {
-#   ctmm::as.telemetry(as_move(x, ...))
-# }
+# as_telemetry -----------------------------------------------------------------
+#' @export
+#' @rdname coercion
+#' @examples
+#' data(deer)
+#' as_telemetry(deer)
+as_telemetry <- function(x, ...) {
+  UseMethod("as_telemetry", x)
+}
+
+#' @export
+#' @rdname coercion
+as_telemetry.track_xyt <- function(x, ...) {
+  if (!amt::has_crs(x)) {
+    stop("track needs to havea CRS.")
+  }
+  x <- transform_coords(x, sp::CRS("+init=epsg:4326"))
+  ctmm::as.telemetry(data.frame(lon = x$x_, lat = x$y_, timestamp = x$t_))
+}
 
 
 # as_moveHMM --------------------------------------------------------------
@@ -159,18 +158,7 @@ as_bcpa.track_xyt <- function(x, ...) {
 #' # Fit HMM with two states
 #' data(deer)
 #' dm <- as_moveHMM(deer)
-#' \dontrun{
-#' mu0 <- rep(mean(dm$step, na.rm = TRUE), 2) # step mean (two parameters: one for each state)
-#' sigma0 <- rep(sd(dm$step, na.rm = TRUE), 2) # step SD
-#' zeromass0 <- c(0.1, 0.05) # step zero-mass
-#' stepPar0 <- c(mu0, sigma0, zeromass0)
-#' angleMean0 <- c(pi, pi) # angle mean
-#' kappa0 <- c(1, 1) # angle concentration
-#' anglePar0 <- c(angleMean0, kappa0) ## call to fitting function
-#' m1 <- fitHMM(data = dm, nbStates = 2,
-#'        stepPar0 = stepPar0, anglePar0 = anglePar0, formula = ~ 1)
-#' }
-#'
+
 as_moveHMM <- function(x, ...) {
   UseMethod("as_moveHMM", x)
 }
