@@ -18,20 +18,15 @@
 #' # track_xyt ---------------------------------------------------------------
 #' # Default settings
 #' rp1 <- random_points(deer)
-#' rp2 <- random_points(deer, hr = "kde") # we need a larger template raster for kde
 #'
 #' \dontrun{
 #' plot(rp1)
-#' plot(rp2)
 #' }
 #'
-#' # rp2 does not make sense, because the `trast` is to small.
-#' # this can be overcome by increasing the trast manually.
-#' trast <- raster(bbox(deer, buffer = 2000), res = 30)
+#' trast <- raster(bbox(deer, buffer = 5000), res = 30)
 #' rp3 <- random_points(deer, hr = "kde", trast = trast) # we need a larger template raster
 #'
 #'  \dontrun{
-#' plot(rp2)
 #' plot(rp3)
 #' }
 #'
@@ -80,8 +75,8 @@ random_points.mcp <- function(x, n = 100, type = "random", ...) {
 
 #' @export
 #' @rdname random_points
-random_points.kde <- function(x, n = 100, type = "random", ...) {
-  as_track(sp::spsample(hr_isopleths(x), n = n, type = type, ...))
+random_points.SpatialPolygons <- function(x, n = 100, type = "random", ...) {
+  as_track(sp::spsample(x, n = n, type = type, ...))
 }
 
 #' @export
@@ -91,17 +86,18 @@ random_points.track_xy <- function(x, level = 1, hr = "mcp", factor = 10, type =
   if (hr == "mcp") {
     hr <- hr_mcp(x, levels = level, ...)
   } else if (hr == "kde") {
-    hr <- hr_kde(x, levels = level, ...)
+    hr <- hr_kde(x, ...) %>% hr_isopleths(level = level)
   } else {
     stop("Only mcp and kde home ranges are currently implemented.")
   }
 
-  rnd_pts <- random_points(hr, n = round(nrow(x)) * factor, type = type)
+  rnd_pts <- random_points(hr, n = round(nrow(x)) * factor, type = type, level = level)
 
   n <- nrow(x)
   n_rnd <- nrow(rnd_pts)
 
-  xx <- data_frame(
+
+  xx <- tibble(
     case_ = c(rep(TRUE, n), rep(FALSE, n_rnd)),
     x_ = c(x$x_, rnd_pts$x_),
     y_ = c(x$y_, rnd_pts$y_)
